==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/d4/d48c710bbac51ea00a9cb3ed7e8dd999.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/StatsBundle/StatEvents.php */
class __TwigTemplate_84fae3d1b8932a7ca0917e14478083e6 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\StatsBundle;

final class StatEvents
{
    /**
     * The mautic.aggregate_stat_request event is dispatched when an aggregate stat is requested.
     *
     * The event listener receives a \\Mautic\\StatsBundle\\Event\\AggregateStatRequestEvent instance.
     *
     * @var string
     */
    public const AGGREGATE_STAT_REQUEST = 'mautic.aggregate_stat_request';
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/StatsBundle/StatEvents.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/StatsBundle/StatEvents.php", "/var/www/html/mauticGIT-Test/app/bundles/StatsBundle/StatEvents.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/d4/d48c710bbac51ea00a9cb3ed7e8dd999.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/StatsBundle/StatEvents.php */
class __TwigTemplate_84fae3d1b8932a7ca0917e14478083e6 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\StatsBundle;

final class StatEvents
{
    /**
     * The mautic.aggregate_stat_request event is dispatched when an aggregate stat is requested.
     *
     * The event listener receives a \\Mautic\\StatsBundle\\Event\\AggregateStatRequestEvent instance.
     *
     * @var string
     */
    public const AGGREGATE_STAT_REQUEST = 'mautic.aggregate_stat_request';
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/StatsBundle/StatEvents.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/StatsBundle/StatEvents.php", "/var/www/html/production-demo/app/bundles/StatsBundle/StatEvents.php");
    }
}
